# ----------------------------------------------------------------------
# pytest-csv - https://github.com/nicoulaj/pytest-csv
# copyright (c) 2018-2021 pytest-csv contributors
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
# ----------------------------------------------------------------------

ID = 'id'
MODULE = 'module'
CLASS = 'class'
FUNCTION = 'function'
NAME = 'name'
FILE = 'file'
DOC = 'doc'
STATUS = 'status'
SUCCESS = 'success'
DURATION = 'duration'
DURATION_FORMATTED = 'duration_formatted'
MESSAGE = 'message'
MARKERS = 'markers'
MARKERS_WITH_ARGS = 'markers_with_args'
MARKERS_AS_COLUMNS = 'markers_as_columns'
MARKERS_ARGS_AS_COLUMNS = 'markers_args_as_columns'
PARAMETERS = 'parameters'
PARAMETERS_AS_COLUMNS = 'parameters_as_columns'
PROPERTIES = 'properties'
PROPERTIES_AS_COLUMNS = 'properties_as_columns'
HOST = 'host'
USER = 'user'
SYSTEM = 'system'
SYSTEM_RELEASE = 'system_release'
SYSTEM_VERSION = 'system_version'
PYTHON_IMPLEMENTATION = 'python_implementation'
PYTHON_VERSION = 'python_version'
WORKING_DIRECTORY = 'working_directory'
