# ----------------------------------------------------------------------
# pytest-csv - https://github.com/nicoulaj/pytest-csv
# copyright (c) 2018-2021 pytest-csv contributors
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
# ----------------------------------------------------------------------


__prog__ = 'pytest-csv'
__author__ = 'Julien Nicoulaud'
__email__ = 'julien.nicoulaud@gmail.com'
__url__ = 'https://github.com/nicoulaj/pytest-csv'
__copyright__ = 'copyright 2018 pytest-csv contributors'
__license__ = 'GPLv3'
__description__ = 'CSV output for pytest.'
__keywords__ = 'py.test pytest csv tsv report'
__version__ = '3.0.0'
